import * as react from 'react';
import { PropsWithChildren, HTMLAttributes, ElementType, CSSProperties } from 'react';

declare const RADIUS_TOKEN: {
    /**
     * Content banners(Primary), Full-screen dialogs, Lists, Navigation bars, Header Progress indicators, Side sheets, Tabs, Top app bars
     */
    readonly "rounded-none": "0";
    /**
     * Tooltip pointer
     */
    readonly "rounded-xsmall": "1px";
    /**
     * Buttons(Small, Tiny), Checkbox, Segment tab item
     */
    readonly "rounded-small": "6px";
    /**
     * Buttons(Large, Medium), Content banners(Secondary), Context menu, Optionlist, Select, Textfield, Text area, Tooltip
     */
    readonly "rounded-base": "8px";
    /**
     * Page banner, Card
     */
    readonly "rounded-large": "12px";
    /**
     * Modal
     */
    readonly "rounded-xlarge": "16px";
    /**
     * Avata, Slider Track, Switch, Tag, Toast
     */
    readonly "rounded-full": "999999px";
};

declare const THICKNESS_TOKEN: {
    /**
     * Default
     */
    "border-1": string;
    /**
     * 파일 업로더 Drag on 상태 border 캠페인 채널 Card hover 또는 유효성 에러 상태 border (MP)
     */
    "border-2": string;
    /**
     * Content banner(Primary) 왼쪽 사이드 border
     */
    "border-4": string;
    /**
     * System icon(Line) border
     */
    "border-icon": string;
    /**
     * 가로 요소 사이에 테두리를 추가합니다.
     */
    "divide-x": string;
    /**
     * 쌓인 요소 사이에 테두리를 추가합니다.
     */
    "divide-y": string;
};

declare const PALETTE_TOKEN: {
    readonly "slate-50": "#F8F9FB";
    readonly "slate-100": "#E2E5E9";
    readonly "slate-200": "#DBDEE3";
    readonly "slate-300": "#BCC0C6";
    readonly "slate-400": "#9FA3AB";
    readonly "slate-500": "#717680";
    readonly "slate-600": "#4B515B";
    readonly "slate-700": "#24282F";
    readonly "slate-800": "#1D2027";
    readonly "slate-900": "#15181E";
    readonly "slate-tint-15": "rgba(115, 120, 130, 0.15)";
    readonly "slate-black": "#000000";
    readonly "slate-white": "#FFFFFF";
    readonly "imBlue-50": "#E8F0FF";
    readonly "imBlue-100": "#C6DBFF";
    readonly "imBlue-200": "#99BDFF";
    readonly "imBlue-300": "#70A2FF";
    readonly "imBlue-400": "#4788FF";
    readonly "imBlue-500": "#1A6DFF";
    readonly "imBlue-600": "#0056F5";
    readonly "imBlue-700": "#0047CC";
    readonly "imBlue-800": "#0039A3";
    readonly "imBlue-900": "#002B7A";
    readonly "imBlue-tint-15": "rgba(26, 109, 255, 0.15)";
    readonly "mint-50": "#E5FBF6";
    readonly "mint-100": "#CCF7EB";
    readonly "mint-200": "#99F1DA";
    readonly "mint-300": "#73EBCC";
    readonly "mint-400": "#4CE6BF";
    readonly "mint-500": "#00DBA3";
    readonly "mint-600": "#00BA8B";
    readonly "mint-700": "#009972";
    readonly "mint-800": "#00785A";
    readonly "mint-900": "#005841";
    readonly "mint-tint-15": "rgba(0, 219, 163, 0.15)";
    readonly "raspberry-50": "#FFF2F3";
    readonly "raspberry-100": "#FFE6E8";
    readonly "raspberry-200": "#FECDD3";
    readonly "raspberry-300": "#FEA3AC";
    readonly "raspberry-400": "#FE7683";
    readonly "raspberry-500": "#FE5868";
    readonly "raspberry-600": "#DD3344";
    readonly "raspberry-700": "#C81E2E";
    readonly "raspberry-800": "#A51927";
    readonly "raspberry-900": "#88131A";
    readonly "raspberry-tint-15": "rgba(254, 88, 104, 0.15)";
    readonly "mango-50": "#FFF6E7";
    readonly "mango-100": "#FFF2DB";
    readonly "mango-200": "#FFE0AC";
    readonly "mango-300": "#FFD388";
    readonly "mango-400": "#FFC258";
    readonly "mango-500": "#FFA811";
    readonly "mango-600": "#E5970F";
    readonly "mango-700": "#D68C0C";
    readonly "mango-800": "#99650A";
    readonly "mango-900": "#734C08";
    readonly "mango-tint-15": "rgba(255, 168, 17, 0.15)";
    readonly "skyblue-50": "#F3F8FF";
    readonly "skyblue-100": "#E0EFFF";
    readonly "skyblue-200": "#CEE5FF";
    readonly "skyblue-300": "#BCDBFF";
    readonly "skyblue-400": "#AAD1FF";
    readonly "skyblue-500": "#85BDFF";
    readonly "skyblue-600": "#6A97CC";
    readonly "skyblue-700": "#5D84B3";
    readonly "skyblue-800": "#4C6C91";
    readonly "skyblue-900": "#314760";
    readonly "skyblue-tint-15": "rgba(133, 189, 255, 0.15)";
    readonly "grape-50": "#F5EDFF";
    readonly "grape-100": "#EBDBFF";
    readonly "grape-200": "#DCC0FF";
    readonly "grape-300": "#C79CFF";
    readonly "grape-400": "#B378FF";
    readonly "grape-500": "#9A4BFF";
    readonly "grape-600": "#8340D9";
    readonly "grape-700": "#7438BF";
    readonly "grape-800": "#9A4BFF";
    readonly "grape-900": "#55298C";
    readonly "grape-tint-15": "rgba(154, 75, 255, 0.15)";
};

declare const COLOR_TOKEN: Readonly<{
    /**
     * Page 배경색
     */
    bg: {
        light: string;
        dark: "#000000";
    };
    /**
     * Card, Modal, Popover 등의 컴포넌트 배경색
     */
    surface: {
        light: "#FFFFFF";
        dark: "#15181E";
    };
    /**
     * Card, Modal, Popover 등의 컴포넌트 보조 배경색
     */
    "surface-sub": {
        light: "#F8F9FB";
        dark: "#1D2027";
    };
    /**
     * 설명
     */
    "surface-slate": {
        light: "#E2E5E9";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * 설명
     */
    "surface-accent": {
        light: "#F3F8FF";
        dark: "rgba(133, 189, 255, 0.15)";
    };
    /**
     * 배지를 포함한 Critical 요소의 배경 색상으로, 오류 및 즉각적인 조치가 필요한 중요한 이벤트에 사용합니다.
     */
    "surface-critical": {
        light: "#FFF2F3";
        dark: "rgba(254, 88, 104, 0.15)";
    };
    /**
     * 경고 요소의 배경 색상으로, 사용자에게 조치가 필요함을 알리고 배지, 배너 및 예외 목록에 적용됩니다.
     */
    "surface-warning": {
        light: "#FFF6E7";
        dark: "rgba(255, 168, 17, 0.15)";
    };
    /**
     * 배지를 포함한 성공 요소의 배경 색상으로, 사용자 행동의 성공 또는 성장을 설명하는 것과 같이 긍정적인 것을 나타냅니다.
     */
    "surface-success": {
        light: "#E5FBF6";
        dark: "rgba(0, 219, 163, 0.15)";
    };
    /**
     * 정보 요소의 배경 색상으로, 즉각적인 조치가 필요하지 않은 중요한 요소를 나타냅니다. 정보 배너 및 배지, 새로운 정보에 주의를 환기시키는 표시기, 로드 또는 진행률 표시줄, 데이터 시각화와 함께 사용됩니다.
     */
    "surface-highlight": {
        light: "#F3F8FF";
        dark: "rgba(133, 189, 255, 0.15)";
    };
    /** Primary textfield 배경색 */
    "field-primary": {
        light: "#E8F0FF";
        dark: "rgba(26, 109, 255, 0.15)";
    };
    /** Secondary textfield 배경색 */
    "field-secondary": {
        light: "#F8F9FB";
        dark: "#24282F";
    };
    /**
     * Textfield의 Typing 상태
     * 선택된 체크박스와 라디오 버튼의 채우기 색상
     */
    focus: {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button 배경색
     */
    "action-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button hover color
     */
    "action-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Primary button pressed color
     */
    "action-primary-pressed": {
        light: "#99BDFF";
        dark: "#99BDFF";
    };
    /**
     * Primary button disabled color
     */
    "action-primary-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Secondary button 배경색
     */
    "action-secondary": {
        light: "#FFFFFF";
        dark: "#15181E";
    };
    /**
     * secondary button hover color
     */
    "action-secondary-hover": {
        light: "#F8F9FB";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * secondary button pressed color
     */
    "action-secondary-pressed": {
        light: "#E2E5E9";
        dark: "#24282F";
    };
    /**
     * secondary button disabled color
     */
    "action-secondary-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Floating action button(FAB) 배경색
     */
    "action-tertiary": {
        light: "#15181E";
        dark: "#1D2027";
    };
    /**
     * Floating action button(FAB) hover color
     */
    "action-tertiary-hover": {
        light: "#24282F";
        dark: "#4B515B";
    };
    /**
     * Critical button 배경색
     */
    "action-critical": {
        light: "#FE5868";
        dark: "#FE5868";
    };
    /**
     * Critical button hover color
     */
    "action-critical-hover": {
        light: "#FEA3AC";
        dark: "#FE7683";
    };
    /**
     * Critical button pressed color
     */
    "action-critical-pressed": {
        light: "#FECDD3";
        dark: "#FEA3AC";
    };
    /**
     * Critical button disabled color
     */
    "action-critical-disabled": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Floating action button(FAB) 배경색
     */
    "action-toggle": {
        light: "rgba(115, 120, 130, 0.15)";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * 특정 요소를 투명도가 있는 어두운 색상으로 가려야 할 때 사용 (Modal, Side sheet)
     */
    backdrop: {
        light: string;
        dark: string;
    };
    /**
     * Default border color
     */
    border: {
        light: "#DBDEE3";
        dark: "rgba(115, 120, 130, 0.15)";
    };
    /**
     * Default border hover color (액션 기능이 있을 경우)
     */
    "border-hover": {
        light: "#70A2FF";
        dark: "#0047CC";
    };
    /**
     * Sub border color
     */
    "border-sub": {
        light: "#717680";
        dark: "#4B515B";
    };
    /**
     * Sub border color
     */
    "border-minimal": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical border color
     */
    "border-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical border hover color (액션 기능이 있을 경우)
     */
    "border-critical-hover": {
        light: "#FEA3AC";
        dark: "#FECDD3";
    };
    /**
     * Warning border color
     */
    "border-warning": {
        light: "#E5970F";
        dark: "#FFC258";
    };
    /**
     * Success border color
     */
    "border-success": {
        light: "#00BA8B";
        dark: "#4CE6BF";
    };
    /**
     * Informative border color
     */
    "border-highlight": {
        light: "#4C6C91";
        dark: "#6A97CC";
    };
    /**
     * 요소 사이 구분 선
     */
    divide: {
        light: "#E2E5E9";
        dark: "#1D2027";
    };
    /**
     * 요소 사이의 보조 구분 선
     */
    "divide-sub": {
        light: "#717680";
        dark: "#1D2027";
    };
    /**
     * 요소 사이의 보조 구분 선
     */
    "divide-minimal": {
        light: "#F8F9FB";
        dark: "#1D2027";
    };
    /**
     * Default text, Primary label color
     */
    text: {
        light: "#15181E";
        dark: "#FFFFFF";
    };
    /**
     * Sub text, Secondary label, Placeholder color
     */
    "text-sub": {
        light: "#717680";
        dark: "#717680";
    };
    /**
     * Disabled text, Placeholder disabled text color
     */
    "text-disabled": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical state text color
     */
    "text-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical text hover color (액션 기능이 있을 경우)
     */
    "text-critical-hover": {
        light: "#FE7683";
        dark: "#FECDD3";
    };
    /**
     * Warning state text color
     */
    "text-warning": {
        light: "#D68C0C";
        dark: "#FFC258";
    };
    /**
     * Warning text hover color (액션 기능이 있을 경우)
     */
    "text-warning-hover": {
        light: "#FFC258";
        dark: "#FFE0AC";
    };
    /**
     * Success text color
     */
    "text-success": {
        light: "#009972";
        dark: "#4CE6BF";
    };
    /**
     * Link text, Primary text button color
     */
    "text-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Link text, Primary text button hover color
     */
    "text-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Secondary text button color
     */
    "text-secondary": {
        light: "#717680";
        dark: "#BCC0C6";
    };
    /**
     * Secondary text button hover color
     */
    "text-secondary-hover": {
        light: "#9FA3AB";
        dark: "#DBDEE3";
    };
    /**
     * Primary, Critical, Text on button text color
     */
    "text-on": {
        light: "#FFFFFF";
        dark: "#FFFFFF";
    };
    /**
     * Default icon color
     */
    icon: {
        light: "#15181E";
        dark: "#FFFFFF";
    };
    /**
     * Sub icon color
     */
    "icon-sub": {
        light: "#717680";
        dark: "#717680";
    };
    /**
     * Disabled icon color
     */
    "icon-disabled": {
        light: "#BCC0C6";
        dark: "#4B515B";
    };
    /**
     * Error, Critical state icon color
     */
    "icon-critical": {
        light: "#DD3344";
        dark: "#FE7683";
    };
    /**
     * Error, Critical icon hover color (액션 기능이 있을 경우)
     */
    "icon-critical-hover": {
        light: "#FE7683";
        dark: "#FECDD3";
    };
    /**
     * Warning state icon color
     */
    "icon-warning": {
        light: "#D68C0C";
        dark: "#FFC258";
    };
    /**
     * Warning icon hover color (액션 기능이 있을 경우)
     */
    "icon-warning-hover": {
        light: "#FFC258";
        dark: "#FFE0AC";
    };
    /**
     * Success icon color
     */
    "icon-success": {
        light: "#009972";
        dark: "#4CE6BF";
    };
    /**
     * Primary button icon color
     */
    "icon-primary": {
        light: "#1A6DFF";
        dark: "#4788FF";
    };
    /**
     * Primary button icon hover color
     */
    "icon-primary-hover": {
        light: "#70A2FF";
        dark: "#70A2FF";
    };
    /**
     * Secondary button icon color
     */
    "icon-secondary": {
        light: "#717680";
        dark: "#BCC0C6";
    };
    /**
     * Secondary button icon hover color
     */
    "icon-secondary-hover": {
        light: "#9FA3AB";
        dark: "#DBDEE3";
    };
    /**
     * Primary, Critical, Text on button text color
     */
    "icon-on": {
        light: "#FFFFFF";
        dark: "#FFFFFF";
    };
}>;

declare const SHADOW_TOKEN: {
    readonly "dropShadow-none": "0px 0px 0px 0px rgba(75, 81, 91, 0.00)";
    readonly "dropShadow-popover": "0px 2px 10px 0px rgba(75, 81, 91, 0.10), 0px 0px 2px 0px rgba(75, 81, 91, 0.20)";
    readonly "dropShadow-pageAside": "0px 0px 24px 0px rgba(75, 81, 91, 0.04), -1px 0px 0px 0px rgba(75, 81, 91, 0.04), 0px 0px 12px 0px rgba(75, 81, 91, 0.04)";
    readonly "dropShadow-card": "10px 20px 30px 0px rgba(75, 81, 91, 0.12)";
    readonly "dropShadow-layer": "0px 14px 32px 0px rgba(75, 81, 91, 0.12), 0px 10px 14px 0px rgba(75, 81, 91, 0.06), 0px 0px 0px 1px rgba(75, 81, 91, 0.03), 0px 0px 1px 0px rgba(75, 81, 91, 0.20)";
    readonly "dropShadow-modal": "0px 25px 80px 0px rgba(75, 81, 91, 0.20), 0px 0px 1px 0px rgba(75, 81, 91, 0.20)";
};

declare const SPACING_TOKEN: {
    readonly "space-0": "0";
    readonly "space-px": "1px";
    readonly "space-05": "2px";
    readonly "space-1": "4px";
    readonly "space-15": "6px";
    readonly "space-2": "8px";
    readonly "space-25": "10px";
    readonly "space-3": "12px";
    readonly "space-4": "16px";
    readonly "space-5": "20px";
    readonly "space-6": "24px";
    readonly "space-7": "28px";
    readonly "space-8": "32px";
    readonly "space-10": "40px";
    readonly "space-12": "48px";
    readonly "space-16": "64px";
    readonly "space-20": "80px";
    readonly "space-24": "96px";
    readonly "space-28": "112px";
    readonly "space-32": "128px";
    readonly "space-40": "160px";
    readonly "space-auto": "auto";
};

declare const CORE_TOKEN: {
    readonly fontFamily: "Pretendard";
    readonly fontSize: {
        readonly "2xsmall": "11px";
        readonly xsmall: "0.75rem";
        readonly small: "0.875rem";
        readonly base: "1rem";
        readonly large: "1.125rem";
        readonly xlarge: "1.25rem";
        readonly "2xlarge": "1.5rem";
        readonly "3xlarge": "1.875rem";
        readonly "4xlarge": "2.25rem";
    };
    readonly fontWeight: {
        readonly normal: 400;
        readonly medium: 500;
        readonly semibold: 600;
        readonly bold: 700;
    };
    readonly lineHeight: {
        readonly "leading-3": "0.75rem";
        readonly "leading-4": "1rem";
        readonly "leading-5": "1.25rem";
        readonly "leading-6": "1.5rem";
        readonly "leading-7": "1.75rem";
        readonly "leading-8": "2rem";
        readonly "leading-9": "2.25rem";
        readonly "leading-10": "2.5rem";
        readonly "leading-none": "100%";
        readonly "leading-tight": "125%";
        readonly "leading-snug": "137.5%";
        readonly "leading-normal": "150%";
        readonly "leading-relaxed": "162.5%";
        readonly "leading-loose": "200%";
    };
};

declare const Semantic: {
    /** 프로모션 비주얼 타이틀 */
    readonly h1: {
        readonly fontWeight: 400;
        readonly fontSize: "2.25rem";
        readonly lineHeight: "2.5rem";
    };
    /** 프로모션 비주얼 타이틀(강조시에만 사용) */
    readonly "h1-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "2.25rem";
        readonly lineHeight: "2.5rem";
    };
    /** 페이지 타이틀 */
    readonly "h2-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1.875rem";
        readonly lineHeight: "2.25rem";
    };
    /** 오늘의 할 일, 통계 등의 숫자 요약 primary */
    readonly "h3-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1.5rem";
        readonly lineHeight: "1.75rem";
    };
    /** 오늘의 할 일, 통계 등의 숫자 요약 primary */
    readonly "h4-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1.25rem";
        readonly lineHeight: "1.5rem";
    };
    /** 프로모션 배너 타이틀 */
    readonly h5: {
        readonly fontWeight: 400;
        readonly fontSize: "1.125rem";
        readonly lineHeight: "1.75rem";
    };
    /** 카드 타이틀, 프로모션 배너 타이틀(강조시에만 사용) */
    readonly "h5-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1.125rem";
        readonly lineHeight: "1.75rem";
    };
    readonly h6: {
        readonly fontWeight: 400;
        readonly fontSize: "1rem";
        readonly lineHeight: "1.5rem";
    };
    /** (only card) 서브 타이틀 */
    readonly "h6-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1rem";
        readonly lineHeight: "1.5rem";
    };
    /** 큰 버튼 텍스트 */
    readonly p16: {
        readonly fontWeight: 400;
        readonly fontSize: "1rem";
        readonly lineHeight: "1.5rem";
    };
    readonly "p16-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "1rem";
        readonly lineHeight: "1.5rem";
    };
    /** 기본 텍스트 */
    readonly p14: {
        readonly fontWeight: 400;
        readonly fontSize: "0.875rem";
        readonly lineHeight: "1.25rem";
    };
    /** 기본 텍스트(강조시에만 사용) */
    readonly "p14-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "0.875rem";
        readonly lineHeight: "1.25rem";
    };
    /** 서브 텍스트 */
    readonly p12: {
        readonly fontWeight: 400;
        readonly fontSize: "0.75rem";
        readonly lineHeight: "1rem";
    };
    /** 서브 텍스트(강조시에만 사용) */
    readonly "p12-bold": {
        readonly fontWeight: 700;
        readonly fontSize: "0.75rem";
        readonly lineHeight: "1rem";
    };
    /** 라벨 */
    readonly l14: {
        readonly fontWeight: 700;
        readonly fontSize: "0.875rem";
        readonly lineHeight: "1.25rem";
    };
    /** tag, chips, badge, etc */
    readonly l11: {
        readonly fontWeight: 400;
        readonly fontSize: "11px";
        readonly lineHeight: "0.75rem";
    };
};

interface TypographyProps extends PropsWithChildren, HTMLAttributes<HTMLParagraphElement> {
    as?: ElementType;
    semanticToken?: keyof typeof Semantic;
    style?: CSSProperties;
}
declare const Typography: react.ForwardRefExoticComponent<TypographyProps & react.RefAttributes<HTMLElement>>;

declare const FONT_SIZE: {
    readonly "2xsmall": "11px";
    readonly xsmall: "0.75rem";
    readonly small: "0.875rem";
    readonly base: "1rem";
    readonly large: "1.125rem";
    readonly xlarge: "1.25rem";
    readonly "2xlarge": "1.5rem";
    readonly "3xlarge": "1.875rem";
    readonly "4xlarge": "2.25rem";
};

declare const FONT_WEIGHT: {
    readonly normal: 400;
    readonly medium: 500;
    readonly semibold: 600;
    readonly bold: 700;
};

declare const LINE_HEIGHT: {
    readonly "leading-3": "0.75rem";
    readonly "leading-4": "1rem";
    readonly "leading-5": "1.25rem";
    readonly "leading-6": "1.5rem";
    readonly "leading-7": "1.75rem";
    readonly "leading-8": "2rem";
    readonly "leading-9": "2.25rem";
    readonly "leading-10": "2.5rem";
    readonly "leading-none": "100%";
    readonly "leading-tight": "125%";
    readonly "leading-snug": "137.5%";
    readonly "leading-normal": "150%";
    readonly "leading-relaxed": "162.5%";
    readonly "leading-loose": "200%";
};

export { COLOR_TOKEN, CORE_TOKEN, FONT_SIZE, FONT_WEIGHT, LINE_HEIGHT, PALETTE_TOKEN, RADIUS_TOKEN, SHADOW_TOKEN, SPACING_TOKEN, Semantic, THICKNESS_TOKEN, Typography };
